<Query Kind="Statements" />

// Declaration of variables
string Secret, Domain; List<Product> Products = new List<Product>();

/*** START ***/
// 1. Insert your secret key from the shop administration:
Secret = "07FnpNB9Qk8q";

// 2. Insert your domain:
Domain = "https://eksempel-shop.dk";

// 3. Each line below represents one product. Duplicate the lines to add more products to the basket.
//    Structure: Products.Add(new Product(Item number, ID, Title, Variant ID, Quantity, Price, Currency, Weight));
//    Note: Optional values that you do not want to include are indicated as "" and 0 for text and numeric values.
Products.Add(new Product("", 26, "Product 1 (quotation according to agreement)", 0, 1, 26.79, "", 0));
Products.Add(new Product("", 8, "Product 2", 0, 1, 649.22, "", 0));
Products.Add(new Product("", 2, "Product 3 (variant)", 36, 1, 150, "", 0));

// 4. Press F5 on your keyboard or click the "play button" in the top menu of LINQPad.
// Then the code is run and the generated link is displayed in the "Results" window below.
/*** END ***/

// The code below handles the technicalities of building the basket link
string productsJson = SerializeProducts(Products);
string secretPlusJson = Secret + productsJson;
string hash = System.Security.Cryptography.SHA1.Create().ComputeHash(Encoding.UTF8.GetBytes(secretPlusJson)).Aggregate(string.Empty, (x, y) => x + y.ToString("x2"));
// Combine URL with parameters and hash code
string url = Domain + "/actions/cart/addmulti/?input=" + productsJson + "&code=" + hash;
// Display output
("Generated link:").Dump();
url.Dump();
("\n").Dump();
// Display object data
Products.Dump("Product objects (program variables and JSON properties)");
// Helper method
static string SerializeProducts(List<Product> Products)
{
	string temp = string.Empty;
	if (Products.Count > 0)
	{
		temp = "[";
		for (int i = 0; i < Products.Count; i++)
		{
			temp += "{" + Products[i].GetValuesForUrl() + "}";
			if (i < Products.Count -1)
			{
				temp += ",";
			}
		}
		temp += "]";
	}
	return temp;
}
// Helper class
class Product
{
	public string sku, id, title, variant, amount, price, weight, currency;
	public Product(string Sku, int Id, string Title, int VariantId, int Amount, double Price, string Currency, double Weight)
	{
		sku = Sku;
		id = Convert.ToString(Id);
		title = Title;
		variant = Convert.ToString(VariantId);
		amount = Convert.ToString(Amount);
		price = Price.ToString("0.00", System.Globalization.CultureInfo.CreateSpecificCulture("en-US"));
		currency = Currency;
		weight = Weight.ToString("0.0", System.Globalization.CultureInfo.CreateSpecificCulture("en-US"));
	}

	public string Sku
	{
		get
		{
			if (!string.IsNullOrEmpty(sku))
			{
				return "\"sku\":" + "\"" + sku + "\""; // System.Web.HttpUtility.UrlEncode()
			}
			return string.Empty;
		}
	}
	public string Id
	{
		get
		{
			if (!string.IsNullOrEmpty(id) && id != "0")
			{
				return "\"product\":" + id;
			}
			return string.Empty;
		}
	}
	public string Title	{
		get
		{
			if (!string.IsNullOrEmpty(title))
			{
				return "\"title\":" + "\"" + title + "\""; // System.Web.HttpUtility.UrlEncode()
			}
			return string.Empty;
		}
	}
	public string VariantId
	{
		get
		{
			if (!string.IsNullOrEmpty(variant) && variant != "0")
			{
				return "\"variant\":" + variant;
			}
			return string.Empty;
		}
	}
	public string Amount
	{
		get
		{
			if (!string.IsNullOrEmpty(amount))
			{
				return "\"amount\":" + amount;
			}
			return string.Empty;
		}
	}
	public string Price
	{
		get
		{
			if (!string.IsNullOrEmpty(price) && price != "0.00")
			{
				return "\"price\":" + price;
			}
			return string.Empty;
		}
	}
	public string Currency
	{
		get
		{
			if (!string.IsNullOrEmpty(currency))
			{
				return "\"currency\":" + "\"" + currency + "\"";
			}
			return string.Empty;
		}
	}
	public string Weight
	{
		get
		{
			if (!string.IsNullOrEmpty(weight) && weight != "0.0")
			{
				return "\"weight\":" + weight;
			}
			return string.Empty;
		}
	}

	public string GetValuesForUrl()
	{
		string temp = Util(Sku) + Util(Id) + Util(Title) + Util(VariantId) + Util(Amount) + Util(Price) + Util(Currency) + Util(Weight);
		if (!string.IsNullOrEmpty(temp) && temp[temp.Length - 1] == ',') // Remove the last comma
		{
			temp = temp.Substring(0, temp.Length -1);
		}
	  	return temp;
	}

	private string Util(string input)
	{
		if (!string.IsNullOrEmpty(input))
		{
			return input + ",";
		}
		return string.Empty;
	}
}